@@ -10,7 +10,7 @@ class VersionChangedError(ValidationError):
 class RecordModifiedError(DatabaseError):
     def __init__(self, *args, **kwargs):
         self.target = kwargs.pop('target')
-        super(RecordModifiedError, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 
 class VersionError(SuspiciousOperation):
