@@ -2,8 +2,6 @@ import os
 import platform
 import sys
 
-import django
-
 import pytest
 
 py_impl = getattr(platform, 'python_implementation', lambda: None)
@@ -21,7 +19,6 @@ skipIfDjangoVersion = lambda v: pytest.mark.skipif("django.VERSION[:2]{}".format
 
 
 def pytest_configure():
-    from django.contrib.auth.models import Group
     from django.conf import settings
 
     settings.SILENCED_SYSTEM_CHECKS = ['concurrency.W001']
