@@ -1,10 +1,5 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-import django
-
 import pytest
 from demo.models import TriggerConcurrentModel
 
@@ -16,8 +11,6 @@ def obj():
     return TriggerConcurrentModel.objects.create()
 
 
-@pytest.mark.skipif(django.VERSION[:2] < (1, 7),
-                    reason="Skip if django< 1.7")
 @pytest.mark.django_db
 def test_check(obj, monkeypatch):
     from django.core.checks import Warning
