@@ -1,16 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import pytest
 from demo.models import ReversionConcurrentModel
+from django.urls import reverse
 from reversion import add_to_revision, revisions, set_comment
 from reversion.models import Version
 
-try:
-    from django.core.urlresolvers import reverse
-except ImportError:
-    from django.urls import reverse
-
 
 @pytest.mark.django_db
 @pytest.mark.functional
