@@ -1,12 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-from django.test import TestCase
-
 import pytest
 from demo.models import SimpleConcurrentModel
+from django.test import TestCase
 
 import concurrency.fields
 from concurrency.utils import ConcurrencyTestMixin, deprecated, fqn
